PCB Environment: math::Mat4 Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Attributes
math::Mat4 Class Reference

## Public Member Functions
| Mat4 (Real all)
| Mat4 (const Real *)
const Real * | data () const
Real & | operator[] (uint i)
Real | operator[] (uint i) const
Mat4 & | operator= (const Mat4 &)
Mat4 & | operator+= (const Mat4 &)
Mat4 | operator+ (const Mat4 &) const
Mat4 & | operator-= (const Mat4 &)
Mat4 | operator- (const Mat4 &) const
Mat4 & | operator*= (Real)
Mat4 | operator* (Real) const
Mat4 & | operator*= (const Mat4 &)
Mat4 | operator* (const Mat4 &) const
Mat4 & | setOrtho (const Vector_3 &L_B_N, const Vector_3 &R_T_F)
std::string | str () const

## Static Public Attributes
static const Mat4 | ID
static const Mat4 | ZERO

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Math/Mat4.hpp